console games
=============

One game has been prototyped: Geometry Bash!

.. image:: https://raw.githubusercontent.com/maxzheng/console-games/master/docs/geometry_bash.jpeg
 :alt: Geometry Bash

Don't like geometry? You will love this one! :D

To install using autopip_::

    sudo pip3 install autopip
    app install console-games

If you have trouble using `autopip`, you can install using `pip3` directly too.

And then start playing::

    play

Enjoy! And come back soon for more games!!

Links & Contact Info
====================

| PyPI Package: https://pypi.python.org/pypi/console-games
| GitHub Source: https://github.com/maxzheng/console-games
| Report Issues/Bugs: https://github.com/maxzheng/console-games/issues
|
| Connect: https://www.linkedin.com/in/maxzheng
| Contact: maxzheng.os @t gmail.com

.. _autopip: https://pypi.python.org/pypi/autopip
